@@ -67,7 +67,7 @@
 #include "camel-stream-fs.h"
 #include "camel-stream-mem.h"
 
-#define d(x) 
+#define d(x)
 
 #ifdef GPG_LOG
 static int logid;
@@ -88,15 +88,15 @@ camel_gpg_context_new (CamelSession *session)
 {
 	CamelCipherContext *cipher;
 	CamelGpgContext *ctx;
-	
+
 	g_return_val_if_fail (CAMEL_IS_SESSION (session), NULL);
-	
+
 	ctx = (CamelGpgContext *) camel_object_new (camel_gpg_context_get_type ());
-	
+
 	cipher = (CamelCipherContext *) ctx;
 	cipher->session = session;
 	camel_object_ref (session);
-	
+
 	return cipher;
 }
 
@@ -113,7 +113,7 @@ void
 camel_gpg_context_set_always_trust (CamelGpgContext *ctx, gboolean always_trust)
 {
 	g_return_if_fail (CAMEL_IS_GPG_CONTEXT (ctx));
-	
+
 	ctx->always_trust = always_trust;
 }
 
@@ -136,7 +136,7 @@ gpg_hash_to_id (CamelCipherContext *context, CamelCipherHash hash)
 	case CAMEL_CIPHER_HASH_HAVAL5160:
 		return "pgp-haval-5-160";
 	}
-	
+
 	return NULL;
 }
 
@@ -157,7 +157,7 @@ gpg_id_to_hash (CamelCipherContext *context, const char *id)
 		else if (!strcmp (id, "haval-5-160"))
 			return CAMEL_CIPHER_HASH_HAVAL5160;
 	}
-	
+
 	return CAMEL_CIPHER_HASH_DEFAULT;
 }
 
@@ -168,7 +168,7 @@ enum _GpgCtxMode {
 	GPG_CTX_MODE_ENCRYPT,
 	GPG_CTX_MODE_DECRYPT,
 	GPG_CTX_MODE_IMPORT,
-	GPG_CTX_MODE_EXPORT,
+	GPG_CTX_MODE_EXPORT
 };
 
 enum _GpgTrustMetric {
@@ -185,34 +185,34 @@ struct _GpgCtx {
 	CamelSession *session;
 	GHashTable *userid_hint;
 	pid_t pid;
-	
+
 	char *userid;
 	char *sigfile;
 	GPtrArray *recipients;
 	CamelCipherHash hash;
-	
+
 	int stdin_fd;
 	int stdout_fd;
 	int stderr_fd;
 	int status_fd;
 	int passwd_fd;  /* only needed for sign/decrypt */
-	
+
 	/* status-fd buffer */
 	unsigned char *statusbuf;
 	unsigned char *statusptr;
 	unsigned int statusleft;
-	
+
 	char *need_id;
 	char *passwd;
-	
+
 	CamelStream *istream;
 	CamelStream *ostream;
-	
+
 	GByteArray *diagbuf;
 	CamelStream *diagnostics;
-	
+
 	int exit_status;
-	
+
 	unsigned int exited:1;
 	unsigned int complete:1;
 	unsigned int seen_eof1:1;
@@ -221,9 +221,9 @@ struct _GpgCtx {
 	unsigned int armor:1;
 	unsigned int need_passwd:1;
 	unsigned int send_passwd:1;
-	
+
 	unsigned int bad_passwds:2;
-	
+
 	unsigned int hadsig:1;
 	unsigned int badsig:1;
 	unsigned int errsig:1;
@@ -232,11 +232,11 @@ struct _GpgCtx {
 	unsigned int nopubkey:1;
 	unsigned int nodata:1;
 	unsigned int trust:3;
-	
+
 	unsigned int diagflushed:1;
-	
+
 	unsigned int utf8:1;
-	
+
 	unsigned int padding:10;
 };
 
@@ -246,7 +246,7 @@ gpg_ctx_new (CamelSession *session)
 	struct _GpgCtx *gpg;
 	const char *charset;
 	CamelStream *stream;
-	
+
 	gpg = g_new (struct _GpgCtx, 1);
 	gpg->mode = GPG_CTX_MODE_SIGN;
 	gpg->session = session;
@@ -258,30 +258,30 @@ gpg_ctx_new (CamelSession *session)
 	gpg->pid = (pid_t) -1;
 	gpg->exit_status = 0;
 	gpg->exited = FALSE;
-	
+
 	gpg->userid = NULL;
 	gpg->sigfile = NULL;
 	gpg->recipients = NULL;
 	gpg->hash = CAMEL_CIPHER_HASH_DEFAULT;
 	gpg->always_trust = FALSE;
 	gpg->armor = FALSE;
-	
+
 	gpg->stdin_fd = -1;
 	gpg->stdout_fd = -1;
 	gpg->stderr_fd = -1;
 	gpg->status_fd = -1;
 	gpg->passwd_fd = -1;
-	
+
 	gpg->statusbuf = g_malloc (128);
 	gpg->statusptr = gpg->statusbuf;
 	gpg->statusleft = 128;
-	
+
 	gpg->bad_passwds = 0;
 	gpg->need_passwd = FALSE;
 	gpg->send_passwd = FALSE;
 	gpg->need_id = NULL;
 	gpg->passwd = NULL;
-	
+
 	gpg->nodata = FALSE;
 	gpg->hadsig = FALSE;
 	gpg->badsig = FALSE;
@@ -290,34 +290,34 @@ gpg_ctx_new (CamelSession *session)
 	gpg->validsig = FALSE;
 	gpg->nopubkey = FALSE;
 	gpg->trust = GPG_TRUST_NONE;
-	
+
 	gpg->istream = NULL;
 	gpg->ostream = NULL;
-	
+
 	stream = camel_stream_mem_new ();
 	gpg->diagbuf = CAMEL_STREAM_MEM (stream)->buffer;
 	gpg->diagflushed = FALSE;
-	
+
 	if ((charset = e_iconv_locale_charset ()) && g_ascii_strcasecmp (charset, "UTF-8") != 0) {
 		CamelMimeFilterCharset *filter;
 		CamelStreamFilter *fstream;
-		
+
 		gpg->utf8 = FALSE;
-		
+
 		if ((filter = camel_mime_filter_charset_new_convert (charset, "UTF-8"))) {
 			fstream = camel_stream_filter_new_with_stream (stream);
 			camel_stream_filter_add (fstream, (CamelMimeFilter *) filter);
 			camel_object_unref (filter);
 			camel_object_unref (stream);
-			
+
 			stream = (CamelStream *) fstream;
 		}
 	} else {
 		gpg->utf8 = TRUE;
 	}
-	
+
 	gpg->diagnostics = stream;
-	
+
 	return gpg;
 }
 
@@ -352,10 +352,10 @@ gpg_ctx_add_recipient (struct _GpgCtx *gpg, const char *keyid)
 {
 	if (gpg->mode != GPG_CTX_MODE_ENCRYPT && gpg->mode != GPG_CTX_MODE_EXPORT)
 		return;
-	
+
 	if (!gpg->recipients)
 		gpg->recipients = g_ptr_array_new ();
-	
+
 	g_ptr_array_add (gpg->recipients, g_strdup (keyid));
 }
 
@@ -399,10 +399,10 @@ gpg_ctx_get_diagnostics (struct _GpgCtx *gpg)
 		camel_stream_flush (gpg->diagnostics);
 		if (gpg->diagbuf->len == 0)
 			return NULL;
-		
+
 		g_byte_array_append (gpg->diagbuf, (guchar *) "", 1);
 	}
-	
+
 	return (const char *) gpg->diagbuf->data;
 }
 
@@ -423,21 +423,21 @@ gpg_ctx_free (struct _GpgCtx *gpg)
 
 	if (gpg->session)
 		camel_object_unref (gpg->session);
-	
+
 	g_hash_table_foreach (gpg->userid_hint, userid_hint_free, NULL);
 	g_hash_table_destroy (gpg->userid_hint);
-	
+
 	g_free (gpg->userid);
-	
+
 	g_free (gpg->sigfile);
-	
+
 	if (gpg->recipients) {
 		for (i = 0; i < gpg->recipients->len; i++)
 			g_free (gpg->recipients->pdata[i]);
-	
+
 		g_ptr_array_free (gpg->recipients, TRUE);
 	}
-	
+
 	if (gpg->stdin_fd != -1)
 		close (gpg->stdin_fd);
 	if (gpg->stdout_fd != -1)
@@ -448,24 +448,24 @@ gpg_ctx_free (struct _GpgCtx *gpg)
 		close (gpg->status_fd);
 	if (gpg->passwd_fd != -1)
 		close (gpg->passwd_fd);
-	
+
 	g_free (gpg->statusbuf);
-	
+
 	g_free (gpg->need_id);
-	
+
 	if (gpg->passwd) {
 		memset (gpg->passwd, 0, strlen (gpg->passwd));
 		g_free (gpg->passwd);
 	}
-	
+
 	if (gpg->istream)
 		camel_object_unref (gpg->istream);
-	
+
 	if (gpg->ostream)
 		camel_object_unref (gpg->ostream);
-	
+
 	camel_object_unref (gpg->diagnostics);
-	
+
 	g_free (gpg);
 }
 
@@ -495,10 +495,10 @@ gpg_ctx_get_argv (struct _GpgCtx *gpg, int status_fd, char **sfd, int passwd_fd,
 	GPtrArray *argv;
 	char *buf;
 	int i;
-	
+
 	argv = g_ptr_array_new ();
 	g_ptr_array_add (argv, "gpg");
-	
+
 	g_ptr_array_add (argv, "--verbose");
 	g_ptr_array_add (argv, "--no-secmem-warning");
 	g_ptr_array_add (argv, "--no-greeting");
@@ -509,15 +509,15 @@ gpg_ctx_get_argv (struct _GpgCtx *gpg, int status_fd, char **sfd, int passwd_fd,
 		g_ptr_array_add (argv, "--batch");
 		g_ptr_array_add (argv, "--yes");
 	}
-	
+
 	*sfd = buf = g_strdup_printf ("--status-fd=%d", status_fd);
 	g_ptr_array_add (argv, buf);
-	
+
 	if (passwd_fd != -1) {
 		*pfd = buf = g_strdup_printf ("--command-fd=%d", passwd_fd);
 		g_ptr_array_add (argv, buf);
 	}
-	
+
 	switch (gpg->mode) {
 	case GPG_CTX_MODE_SIGN:
 		g_ptr_array_add (argv, "--sign");
@@ -582,9 +582,9 @@ gpg_ctx_get_argv (struct _GpgCtx *gpg, int status_fd, char **sfd, int passwd_fd,
 			g_ptr_array_add (argv, gpg->recipients->pdata[i]);
 		break;
 	}
-	
+
 	g_ptr_array_add (argv, NULL);
-	
+
 	return argv;
 }
 
@@ -598,32 +598,32 @@ gpg_ctx_op_start (struct _GpgCtx *gpg)
 	int i, maxfd, errnosave, fds[10];
 	GPtrArray *argv;
 	int flags;
-	
+
 	for (i = 0; i < 10; i++)
 		fds[i] = -1;
-	
+
 	maxfd = gpg->need_passwd ? 10 : 8;
 	for (i = 0; i < maxfd; i += 2) {
 		if (pipe (fds + i) == -1)
 			goto exception;
 	}
-	
+
 	argv = gpg_ctx_get_argv (gpg, fds[7], &status_fd, fds[8], &passwd_fd);
-	
+
 	if (!(gpg->pid = fork ())) {
 		/* child process */
-		
+
 		if ((dup2 (fds[0], STDIN_FILENO) < 0 ) ||
 		    (dup2 (fds[3], STDOUT_FILENO) < 0 ) ||
 		    (dup2 (fds[5], STDERR_FILENO) < 0 )) {
 			_exit (255);
 		}
-		
+
 		/* Dissociate from camel's controlling terminal so
 		 * that gpg won't be able to read from it.
 		 */
 		setsid ();
-		
+
 		maxfd = sysconf (_SC_OPEN_MAX);
 		/* Loop over all fds. */
 		for (i = 3; i < maxfd; i++) {
@@ -631,7 +631,7 @@ gpg_ctx_op_start (struct _GpgCtx *gpg)
 			if (i != fds[7] && i != fds[8])
 				fcntl (i, F_SETFD, FD_CLOEXEC);
 		}
-		
+
 		/* run gpg */
 		execvp ("gpg", (char **) argv->pdata);
 		_exit (255);
@@ -641,11 +641,11 @@ gpg_ctx_op_start (struct _GpgCtx *gpg)
 		g_free (passwd_fd);
 		goto exception;
 	}
-	
+
 	g_ptr_array_free (argv, TRUE);
 	g_free (status_fd);
 	g_free (passwd_fd);
-	
+
 	/* Parent */
 	close (fds[0]);
 	gpg->stdin_fd = fds[1];
@@ -661,30 +661,30 @@ gpg_ctx_op_start (struct _GpgCtx *gpg)
 		flags = fcntl (gpg->passwd_fd, F_GETFL);
 		fcntl (gpg->passwd_fd, F_SETFL, flags | O_NONBLOCK);
 	}
-	
+
 	flags = fcntl (gpg->stdin_fd, F_GETFL);
 	fcntl (gpg->stdin_fd, F_SETFL, flags | O_NONBLOCK);
-	
+
 	flags = fcntl (gpg->stdout_fd, F_GETFL);
 	fcntl (gpg->stdout_fd, F_SETFL, flags | O_NONBLOCK);
-	
+
 	flags = fcntl (gpg->stderr_fd, F_GETFL);
 	fcntl (gpg->stderr_fd, F_SETFL, flags | O_NONBLOCK);
-	
+
 	flags = fcntl (gpg->status_fd, F_GETFL);
 	fcntl (gpg->status_fd, F_SETFL, flags | O_NONBLOCK);
-	
+
 	return 0;
-	
+
  exception:
-	
+
 	errnosave = errno;
-	
+
 	for (i = 0; i < 10; i++) {
 		if (fds[i] != -1)
 			close (fds[i]);
 	}
-	
+
 	errno = errnosave;
 #else
 	/* FIXME: Port me */
@@ -692,7 +692,7 @@ gpg_ctx_op_start (struct _GpgCtx *gpg)
 
 	errno = EINVAL;
 #endif
-	
+
 	return -1;
 }
 
@@ -702,23 +702,23 @@ static const char *
 next_token (const char *in, char **token)
 {
 	const char *start, *inptr = in;
-	
+
 	while (*inptr == ' ')
 		inptr++;
-	
+
 	if (*inptr == '\0' || *inptr == '\n') {
 		if (token)
 			*token = NULL;
 		return inptr;
 	}
-	
+
 	start = inptr;
 	while (*inptr && *inptr != ' ' && *inptr != '\n')
 		inptr++;
-	
+
 	if (token)
 		*token = g_strndup (start, inptr - start);
-	
+
 	return inptr;
 }
 
@@ -729,39 +729,39 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, CamelException *ex)
 	const unsigned char *status;
 	size_t nread, nwritten;
 	int len;
-	
+
  parse:
-	
+
 	inptr = gpg->statusbuf;
 	while (inptr < gpg->statusptr && *inptr != '\n')
 		inptr++;
-	
+
 	if (*inptr != '\n') {
 		/* we don't have enough data buffered to parse this status line */
 		return 0;
 	}
-	
+
 	*inptr++ = '\0';
 	status = gpg->statusbuf;
 
 	if (camel_debug("gpg:status"))
 		printf ("status: %s\n", status);
-	
-	if (strncmp (status, "[GNUPG:] ", 9) != 0) {
+
+	if (strncmp ((const char *) status, "[GNUPG:] ", 9) != 0) {
 		char *message;
-		message = g_locale_to_utf8(status, -1, NULL, NULL, NULL);
+		message = g_locale_to_utf8((const gchar *) status, -1, NULL, NULL, NULL);
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Unexpected GnuPG status message encountered:\n\n%s"),
 				      message);
 		g_free(message);
 		return -1;
 	}
-	
+
 	status += 9;
-	
+
 	if (!strncmp ((char *) status, "USERID_HINT ", 12)) {
 		char *hint, *user;
-		
+
 		status += 12;
 		status = (const unsigned char *) next_token ((char *) status, &hint);
 		if (!hint) {
@@ -769,59 +769,59 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, CamelException *ex)
 					     _("Failed to parse gpg userid hint."));
 			return -1;
 		}
-		
+
 		if (g_hash_table_lookup (gpg->userid_hint, hint)) {
 			/* we already have this userid hint... */
 			g_free (hint);
 			goto recycle;
 		}
-		
+
 		if (gpg->utf8 || !(user = g_locale_to_utf8 ((gchar *) status, -1, &nread, &nwritten, NULL)))
 			user = g_strdup ((gchar *) status);
-		
+
 		g_strstrip (user);
-		
+
 		g_hash_table_insert (gpg->userid_hint, hint, user);
 	} else if (!strncmp ((char *) status, "NEED_PASSPHRASE ", 16)) {
 		char *userid;
-		
+
 		status += 16;
-		
+
 		status = (const unsigned char *) next_token ((char *) status, &userid);
 		if (!userid) {
 			camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
 					     _("Failed to parse gpg passphrase request."));
 			return -1;
 		}
-		
+
 		g_free (gpg->need_id);
 		gpg->need_id = userid;
 	} else if (!strncmp ((char *) status, "NEED_PASSPHRASE_PIN ", 20)) {
 		char *userid;
-		
+
 		status += 20;
-		
+
 		status = (const unsigned char *) next_token ((char *) status, &userid);
 		if (!userid) {
 			camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
 					     _("Failed to parse gpg passphrase request."));
 			return -1;
 		}
-		
+
 		g_free (gpg->need_id);
 		gpg->need_id = userid;
 	} else if (!strncmp ((char *) status, "GET_HIDDEN ", 11)) {
 		const char *name = NULL;
 		char *prompt, *passwd;
 		guint32 flags;
-		
+
 		status += 11;
-		
+
 		if (gpg->need_id && !(name = g_hash_table_lookup (gpg->userid_hint, gpg->need_id)))
 			name = gpg->need_id;
 		else if (!name)
 			name = "";
-		
+
 		if (!strncmp ((char *) status, "passphrase.pin.ask", 18)) {
 			prompt = g_strdup_printf (_("You need a PIN to unlock the key for your\n"
 						    "SmartCard: \"%s\""), name);
@@ -835,12 +835,12 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, CamelException *ex)
 			g_free (prompt);
 			return -1;
 		}
-		
+
 		flags = CAMEL_SESSION_PASSWORD_SECRET | CAMEL_SESSION_PASSPHRASE;
 		if ((passwd = camel_session_get_password (gpg->session, NULL, NULL, prompt, gpg->need_id, flags, ex))) {
 			if (!gpg->utf8) {
 				char *opasswd = passwd;
-				
+
 				if ((passwd = g_locale_to_utf8 (passwd, -1, &nread, &nwritten, NULL))) {
 					memset (opasswd, 0, strlen (opasswd));
 					g_free (opasswd);
@@ -848,41 +848,41 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, CamelException *ex)
 					passwd = opasswd;
 				}
 			}
-			
+
 			gpg->passwd = g_strdup_printf ("%s\n", passwd);
 			memset (passwd, 0, strlen (passwd));
 			g_free (passwd);
-			
+
 			gpg->send_passwd = TRUE;
 		} else {
 			if (!camel_exception_is_set (ex))
 				camel_exception_set (ex, CAMEL_EXCEPTION_USER_CANCEL, _("Canceled."));
 			return -1;
 		}
-		
+
 		g_free (prompt);
 	} else if (!strncmp ((char *) status, "GOOD_PASSPHRASE", 15)) {
 		gpg->bad_passwds = 0;
 	} else if (!strncmp ((char *) status, "BAD_PASSPHRASE", 14)) {
 		gpg->bad_passwds++;
-		
+
 		camel_session_forget_password (gpg->session, NULL, NULL, gpg->need_id, ex);
-		
+
 		if (gpg->bad_passwds == 3) {
 			camel_exception_set (ex, CAMEL_EXCEPTION_SERVICE_CANT_AUTHENTICATE,
 					     _("Failed to unlock secret key: 3 bad passphrases given."));
 			return -1;
 		}
-	} else if (!strncmp (status, "UNEXPECTED ", 11)) {
+	} else if (!strncmp ((const char *) status, "UNEXPECTED ", 11)) {
 		/* this is an error */
 		char *message;
-		message = g_locale_to_utf8(status+11, -1, NULL, NULL, NULL);
+		message = g_locale_to_utf8((const gchar *) status+11, -1, NULL, NULL, NULL);
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Unexpected response from GnuPG: %s"),
 				      message);
 		g_free(message);
 		return -1;
-	} else if (!strncmp (status, "NODATA", 6)) {
+	} else if (!strncmp ((char *) status, "NODATA", 6)) {
 		/* this is an error */
 		/* But we ignore it anyway, we should get other response codes to say why */
 		gpg->nodata = TRUE;
@@ -950,21 +950,21 @@ gpg_ctx_parse_status (struct _GpgCtx *gpg, CamelException *ex)
 			break;
 		}
 	}
-	
+
  recycle:
-	
+
 	/* recycle our statusbuf by moving inptr to the beginning of statusbuf */
 	len = gpg->statusptr - inptr;
 	memmove (gpg->statusbuf, inptr, len);
-	
+
 	len = inptr - gpg->statusbuf;
 	gpg->statusleft += len;
 	gpg->statusptr -= len;
-	
+
 	/* if we have more data, try parsing the next line? */
 	if (gpg->statusptr > gpg->statusbuf)
 		goto parse;
-	
+
 	return 0;
 }
 
@@ -997,10 +997,10 @@ gpg_ctx_op_cancel (struct _GpgCtx *gpg)
 {
 	pid_t retval;
 	int status;
-	
+
 	if (gpg->exited)
 		return;
-	
+
 	kill (gpg->pid, SIGTERM);
 	sleep (1);
 	retval = waitpid (gpg->pid, &status, WNOHANG);
@@ -1071,42 +1071,42 @@ gpg_ctx_op_step (struct _GpgCtx *gpg, CamelException *ex)
 	   the next file descriptor and so on until we've done what we
 	   can to all of them. If one fails along the way, return
 	   -1. */
-	
+
 	if (polls[2].revents & (POLLIN|POLLHUP)) {
 		/* read the status message and decide what to do... */
 		char buffer[4096];
 		ssize_t nread;
-		
+
 		d(printf ("reading from gpg's status-fd...\n"));
-		
+
 		do {
 			nread = read (gpg->status_fd, buffer, sizeof (buffer));
 		} while (nread == -1 && (errno == EINTR || errno == EAGAIN));
 		if (nread == -1)
 			goto exception;
-		
+
 		if (nread > 0) {
 			status_backup (gpg, buffer, nread);
-			
+
 			if (gpg_ctx_parse_status (gpg, ex) == -1)
 				return -1;
 		} else {
 			gpg->complete = TRUE;
 		}
 	}
-	
+
 	if ((polls[0].revents & (POLLIN|POLLHUP)) && gpg->ostream) {
 		char buffer[4096];
 		ssize_t nread;
-		
+
 		d(printf ("reading gpg's stdout...\n"));
-		
+
 		do {
 			nread = read (gpg->stdout_fd, buffer, sizeof (buffer));
 		} while (nread == -1 && (errno == EINTR || errno == EAGAIN));
 		if (nread == -1)
 			goto exception;
-		
+
 		if (nread > 0) {
 			if (camel_stream_write (gpg->ostream, buffer, (size_t) nread) == -1)
 				goto exception;
@@ -1114,89 +1114,89 @@ gpg_ctx_op_step (struct _GpgCtx *gpg, CamelException *ex)
 			gpg->seen_eof1 = TRUE;
 		}
 	}
-	
+
 	if (polls[1].revents & (POLLIN|POLLHUP)) {
 		char buffer[4096];
 		ssize_t nread;
-		
+
 		d(printf ("reading gpg's stderr...\n"));
-		
+
 		do {
 			nread = read (gpg->stderr_fd, buffer, sizeof (buffer));
 		} while (nread == -1 && (errno == EINTR || errno == EAGAIN));
 		if (nread == -1)
 			goto exception;
-		
+
 		if (nread > 0) {
 			camel_stream_write (gpg->diagnostics, buffer, nread);
 		} else {
 			gpg->seen_eof2 = TRUE;
 		}
 	}
-	
+
 	if ((polls[4].revents & (POLLOUT|POLLHUP)) && gpg->need_passwd && gpg->send_passwd) {
 		ssize_t w, nwritten = 0;
 		size_t n;
-		
+
 		d(printf ("sending gpg our passphrase...\n"));
-		
+
 		/* send the passphrase to gpg */
 		n = strlen (gpg->passwd);
 		do {
 			do {
 				w = write (gpg->passwd_fd, gpg->passwd + nwritten, n - nwritten);
 			} while (w == -1 && (errno == EINTR || errno == EAGAIN));
-			
+
 			if (w > 0)
 				nwritten += w;
 		} while (nwritten < n && w != -1);
-		
+
 		/* zero and free our passwd buffer */
 		memset (gpg->passwd, 0, n);
 		g_free (gpg->passwd);
 		gpg->passwd = NULL;
-		
+
 		if (w == -1)
 			goto exception;
-		
+
 		gpg->send_passwd = FALSE;
 	}
-	
+
 	if ((polls[3].revents & (POLLOUT|POLLHUP)) && gpg->istream) {
 		char buffer[4096];
 		ssize_t nread;
-		
+
 		d(printf ("writing to gpg's stdin...\n"));
-		
+
 		/* write our stream to gpg's stdin */
 		nread = camel_stream_read (gpg->istream, buffer, sizeof (buffer));
 		if (nread > 0) {
 			ssize_t w, nwritten = 0;
-			
+
 			do {
 				do {
 					w = write (gpg->stdin_fd, buffer + nwritten, nread - nwritten);
 				} while (w == -1 && (errno == EINTR || errno == EAGAIN));
-				
+
 				if (w > 0)
 					nwritten += w;
 			} while (nwritten < nread && w != -1);
-						
+
 			if (w == -1)
 				goto exception;
-			
+
 			d(printf ("wrote %d (out of %d) bytes to gpg's stdin\n", nwritten, nread));
 		}
-		
+
 		if (camel_stream_eos (gpg->istream)) {
 			d(printf ("closing gpg's stdin\n"));
 			close (gpg->stdin_fd);
 			gpg->stdin_fd = -1;
 		}
 	}
-	
+
 	return 0;
-	
+
  exception:
 	/* always called on an i/o error */
 	camel_exception_setv(ex, CAMEL_EXCEPTION_SYSTEM, _("Failed to execute gpg: %s"), g_strerror(errno));
@@ -1217,17 +1217,17 @@ gpg_ctx_op_exited (struct _GpgCtx *gpg)
 {
 	pid_t retval;
 	int status;
-	
+
 	if (gpg->exited)
 		return TRUE;
-	
+
 	retval = waitpid (gpg->pid, &status, WNOHANG);
 	if (retval == gpg->pid) {
 		gpg->exit_status = status;
 		gpg->exited = TRUE;
 		return TRUE;
 	}
-	
+
 	return FALSE;
 }
 #endif
@@ -1239,7 +1239,7 @@ gpg_ctx_op_wait (struct _GpgCtx *gpg)
 	sigset_t mask, omask;
 	pid_t retval;
 	int status;
-	
+
 	if (!gpg->exited) {
 		sigemptyset (&mask);
 		sigaddset (&mask, SIGALRM);
@@ -1248,7 +1248,7 @@ gpg_ctx_op_wait (struct _GpgCtx *gpg)
 		retval = waitpid (gpg->pid, &status, 0);
 		alarm (0);
 		sigprocmask (SIG_SETMASK, &omask, NULL);
-		
+
 		if (retval == (pid_t) -1 && errno == EINTR) {
 			/* The child is hanging: send a friendly reminder. */
 			kill (gpg->pid, SIGTERM);
@@ -1265,7 +1265,7 @@ gpg_ctx_op_wait (struct _GpgCtx *gpg)
 		status = gpg->exit_status;
 		retval = gpg->pid;
 	}
-	
+
 	if (retval != (pid_t) -1 && WIFEXITED (status))
 		return WEXITSTATUS (status);
 	else
@@ -1287,9 +1287,9 @@ gpg_sign (CamelCipherContext *context, const char *userid, CamelCipherHash hash,
 	int res = -1;
 	CamelMimePart *sigpart;
 	CamelMultipartSigned *mps;
-	
+
 	/* Note: see rfc2015 or rfc3156, section 5 */
-	
+
 	/* FIXME: stream this, we stream output at least */
 	istream = camel_stream_mem_new();
 	if (camel_cipher_canonical_to_stream(ipart, CAMEL_MIME_FILTER_CANON_STRIP|CAMEL_MIME_FILTER_CANON_CRLF|CAMEL_MIME_FILTER_CANON_FROM,
@@ -1324,21 +1324,21 @@ gpg_sign (CamelCipherContext *context, const char *userid, CamelCipherHash hash,
 	gpg_ctx_set_userid (gpg, userid);
 	gpg_ctx_set_istream (gpg, istream);
 	gpg_ctx_set_ostream (gpg, ostream);
-	
+
 	if (gpg_ctx_op_start (gpg) == -1) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Failed to execute gpg: %s"), g_strerror (errno));
 		goto fail;
 	}
-	
+
 	while (!gpg_ctx_op_complete (gpg)) {
 		if (gpg_ctx_op_step (gpg, ex) == -1)
 			goto fail;
 	}
-	
+
 	if (gpg_ctx_op_wait (gpg) != 0) {
 		const char *diagnostics;
-		
+
 		diagnostics = gpg_ctx_get_diagnostics (gpg);
 		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
 				     diagnostics && *diagnostics ? diagnostics :
@@ -1379,10 +1379,10 @@ gpg_sign (CamelCipherContext *context, const char *userid, CamelCipherHash hash,
 	camel_medium_set_content_object((CamelMedium *)opart, (CamelDataWrapper *)mps);
 fail:
 	camel_object_unref(ostream);
-	
+
 	if (gpg)
 		gpg_ctx_free (gpg);
-	
+
 	return res;
 }
 
@@ -1393,15 +1393,15 @@ swrite (CamelMimePart *sigpart)
 	CamelStream *ostream;
 	char *template;
 	int fd, ret;
-	
+
 	template = g_build_filename (g_get_tmp_dir (), "evolution-pgp.XXXXXX", NULL);
 	if ((fd = g_mkstemp (template)) == -1) {
 		g_free (template);
 		return NULL;
 	}
-	
+
 	/* TODO: This should probably just write the decoded message content out, not the part + headers */
-	
+
 	ostream = camel_stream_fs_new_with_fd (fd);
 	ret = camel_data_wrapper_write_to_stream((CamelDataWrapper *)sigpart, ostream);
 	if (ret != -1) {
@@ -1409,15 +1409,15 @@ swrite (CamelMimePart *sigpart)
 		if (ret != -1)
 			ret = camel_stream_close (ostream);
 	}
-	
+
 	camel_object_unref(ostream);
-	
+
 	if (ret == -1) {
 		g_unlink (template);
 		g_free (template);
 		return NULL;
 	}
-	
+
 	return template;
 }
 
@@ -1435,7 +1435,7 @@ gpg_verify (CamelCipherContext *context, CamelMimePart *ipart, CamelException *e
 
 	mps = (CamelMultipart *)camel_medium_get_content_object((CamelMedium *)ipart);
 	ct = ((CamelDataWrapper *)mps)->mime_type;
-	
+
 	/* Inline signature (using our fake mime type) or PGP/Mime signature */
 	if (camel_content_type_is(ct, "multipart", "signed")) {
 		/* PGP/Mime Signature */
@@ -1443,19 +1443,19 @@ gpg_verify (CamelCipherContext *context, CamelMimePart *ipart, CamelException *e
 
 		tmp = camel_content_type_param(ct, "protocol");
 		if (!CAMEL_IS_MULTIPART_SIGNED(mps)
-		    || tmp == NULL  
+		    || tmp == NULL
 		    || g_ascii_strcasecmp(tmp, context->sign_protocol) != 0) {
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Cannot verify message signature: Incorrect message format"));
 			return NULL;
 		}
-	
+
 		if (!(istream = camel_multipart_signed_get_content_stream ((CamelMultipartSigned *) mps, NULL))) {
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Cannot verify message signature: Incorrect message format"));
 			return NULL;
 		}
-	
+
 		if (!(sigpart = camel_multipart_get_part (mps, CAMEL_MULTIPART_SIGNED_SIGNATURE))) {
 			camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Cannot verify message signature: Incorrect message format"));
@@ -1477,7 +1477,7 @@ gpg_verify (CamelCipherContext *context, CamelMimePart *ipart, CamelException *e
 			      _("Cannot verify message signature: Incorrect message format"));
 		return NULL;
 	}
-	
+
 	/* Now start the real work of verifying the message */
 #ifdef GPG_LOG
 	if (camel_debug_start("gpg:sign")) {
@@ -1516,25 +1516,25 @@ gpg_verify (CamelCipherContext *context, CamelMimePart *ipart, CamelException *e
 			goto exception;
 		}
 	}
-	
+
 	camel_stream_reset(istream);
 	gpg = gpg_ctx_new (context->session);
 	gpg_ctx_set_mode (gpg, GPG_CTX_MODE_VERIFY);
 	if (sigfile)
                 gpg_ctx_set_sigfile (gpg, sigfile);
 	gpg_ctx_set_istream (gpg, istream);
-	
+
 	if (gpg_ctx_op_start (gpg) == -1) {
 		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
 				     _("Failed to execute gpg."));
 		goto exception;
 	}
-	
+
 	while (!gpg_ctx_op_complete (gpg)) {
 		if (gpg_ctx_op_step (gpg, ex) == -1)
 			goto exception;
 	}
-	
+
 	gpg_ctx_op_wait (gpg);
 	validity = camel_cipher_validity_new ();
 	diagnostics = gpg_ctx_get_diagnostics (gpg);
@@ -1551,22 +1551,22 @@ gpg_verify (CamelCipherContext *context, CamelMimePart *ipart, CamelException *e
 	} else {
 		validity->sign.status = CAMEL_CIPHER_VALIDITY_SIGN_BAD;
 	}
-	
+
 	gpg_ctx_free (gpg);
-	
+
 	if (sigfile) {
 		g_unlink (sigfile);
 		g_free (sigfile);
 	}
 	camel_object_unref(istream);
-	
+
 	return validity;
-	
+
  exception:
-	
+
 	if (gpg != NULL)
 		gpg_ctx_free (gpg);
-	
+
 	if (istream)
 		camel_object_unref(istream);
 
@@ -1574,7 +1574,7 @@ gpg_verify (CamelCipherContext *context, CamelMimePart *ipart, CamelException *e
 		g_unlink (sigfile);
 		g_free (sigfile);
 	}
-	
+
 	return NULL;
 }
 
@@ -1609,7 +1609,7 @@ gpg_encrypt (CamelCipherContext *context, const char *userid, GPtrArray *recipie
 	for (i = 0; i < recipients->len; i++) {
 		gpg_ctx_add_recipient (gpg, recipients->pdata[i]);
 	}
-	
+
 	if (gpg_ctx_op_start (gpg) == -1) {
 		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM, _("Failed to execute gpg."));
 		goto fail;
@@ -1620,10 +1620,10 @@ gpg_encrypt (CamelCipherContext *context, const char *userid, GPtrArray *recipie
 		if (gpg_ctx_op_step (gpg, ex) == -1)
 			goto fail;
 	}
-	
+
 	if (gpg_ctx_op_wait (gpg) != 0) {
 		const char *diagnostics;
-		
+
 		diagnostics = gpg_ctx_get_diagnostics (gpg);
 		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
 				     diagnostics && *diagnostics ? diagnostics : _("Failed to execute gpg."));
@@ -1679,7 +1679,7 @@ fail:
 fail1:
 	camel_object_unref(istream);
 	camel_object_unref(ostream);
-		
+
 	return res;
 }
 
@@ -1711,7 +1711,7 @@ gpg_decrypt(CamelCipherContext *context, CamelMimePart *ipart, CamelMimePart *op
 
 	ct = camel_mime_part_get_content_type((CamelMimePart *)content);
 	/* Encrypted part (using our fake mime type) or PGP/Mime multipart */
-	if (camel_content_type_is(ct, "multipart", "encrypted")) {	
+	if (camel_content_type_is(ct, "multipart", "encrypted")) {
 		mp = (CamelMultipart *) camel_medium_get_content_object ((CamelMedium *) ipart);
 		if (!(encrypted = camel_multipart_get_part (mp, CAMEL_MULTIPART_ENCRYPTED_CONTENT))) {
 			camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM, _("Failed to decrypt MIME part: protocol error"));
@@ -1728,11 +1728,11 @@ gpg_decrypt(CamelCipherContext *context, CamelMimePart *ipart, CamelMimePart *op
 				_("Cannot decrypt message: Incorrect message format"));
 		return NULL;
 	}
-	
+
 	istream = camel_stream_mem_new();
 	camel_data_wrapper_decode_to_stream (content, istream);
 	camel_stream_reset(istream);
-	
+
 	ostream = camel_stream_mem_new();
 	camel_stream_mem_set_secure((CamelStreamMem *)ostream);
 
@@ -1740,21 +1740,21 @@ gpg_decrypt(CamelCipherContext *context, CamelMimePart *ipart, CamelMimePart *op
 	gpg_ctx_set_mode (gpg, GPG_CTX_MODE_DECRYPT);
 	gpg_ctx_set_istream (gpg, istream);
 	gpg_ctx_set_ostream (gpg, ostream);
-	
+
 	if (gpg_ctx_op_start (gpg) == -1) {
 		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
 				     _("Failed to execute gpg."));
 		goto fail;
 	}
-	
+
 	while (!gpg_ctx_op_complete (gpg)) {
 		if (gpg_ctx_op_step (gpg, ex) == -1)
 			goto fail;
 	}
-	
+
 	if (gpg_ctx_op_wait (gpg) != 0) {
 		const char *diagnostics;
-		
+
 		diagnostics = gpg_ctx_get_diagnostics (gpg);
 		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
 				     diagnostics && *diagnostics ? diagnostics :
@@ -1777,11 +1777,11 @@ gpg_decrypt(CamelCipherContext *context, CamelMimePart *ipart, CamelMimePart *op
 		/* Set mime/type of this new part to application/octet-stream to force type snooping */
 		camel_mime_part_set_content_type(opart, "application/octet-stream");
 	}
-	if (rv != -1) {	
+	if (rv != -1) {
 		valid = camel_cipher_validity_new();
 		valid->encrypt.description = g_strdup(_("Encrypted content"));
 		valid->encrypt.status = CAMEL_CIPHER_VALIDITY_ENCRYPT_ENCRYPTED;
-		
+
 		if (gpg->hadsig) {
 			if (gpg->validsig) {
 				if (gpg->trust == GPG_TRUST_UNDEFINED || gpg->trust == GPG_TRUST_NONE)
@@ -1800,7 +1800,7 @@ gpg_decrypt(CamelCipherContext *context, CamelMimePart *ipart, CamelMimePart *op
 		camel_exception_setv(ex, CAMEL_EXCEPTION_SYSTEM,
 				     _("Unable to parse message content"));
 	}
-	
+
  fail:
 	camel_object_unref(ostream);
 	camel_object_unref(istream);
@@ -1818,22 +1818,22 @@ gpg_import_keys (CamelCipherContext *context, CamelStream *istream, CamelExcepti
 	gpg = gpg_ctx_new (context->session);
 	gpg_ctx_set_mode (gpg, GPG_CTX_MODE_IMPORT);
 	gpg_ctx_set_istream (gpg, istream);
-	
+
 	if (gpg_ctx_op_start (gpg) == -1) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Failed to execute gpg: %s"),
 				      errno ? g_strerror (errno) : _("Unknown"));
 		goto fail;
 	}
-	
+
 	while (!gpg_ctx_op_complete (gpg)) {
 		if (gpg_ctx_op_step (gpg, ex) == -1)
 			goto fail;
 	}
-	
+
 	if (gpg_ctx_op_wait (gpg) != 0) {
 		const char *diagnostics;
-		
+
 		diagnostics = gpg_ctx_get_diagnostics (gpg);
 		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
 				     diagnostics && *diagnostics ? diagnostics :
@@ -1844,7 +1844,7 @@ gpg_import_keys (CamelCipherContext *context, CamelStream *istream, CamelExcepti
 	res = 0;
 fail:
 	gpg_ctx_free (gpg);
-	
+
 	return res;
 }
 
@@ -1859,26 +1859,26 @@ gpg_export_keys (CamelCipherContext *context, GPtrArray *keys, CamelStream *ostr
 	gpg_ctx_set_mode (gpg, GPG_CTX_MODE_EXPORT);
 	gpg_ctx_set_armor (gpg, TRUE);
 	gpg_ctx_set_ostream (gpg, ostream);
-	
+
 	for (i = 0; i < keys->len; i++) {
 		gpg_ctx_add_recipient (gpg, keys->pdata[i]);
 	}
-	
+
 	if (gpg_ctx_op_start (gpg) == -1) {
 		camel_exception_setv (ex, CAMEL_EXCEPTION_SYSTEM,
 				      _("Failed to execute gpg: %s"),
 				      errno ? g_strerror (errno) : _("Unknown"));
 		goto fail;
 	}
-	
+
 	while (!gpg_ctx_op_complete (gpg)) {
 		if (gpg_ctx_op_step (gpg, ex) == -1)
 			goto fail;
 	}
-	
+
 	if (gpg_ctx_op_wait (gpg) != 0) {
 		const char *diagnostics;
-		
+
 		diagnostics = gpg_ctx_get_diagnostics (gpg);
 		camel_exception_set (ex, CAMEL_EXCEPTION_SYSTEM,
 				     diagnostics && *diagnostics ? diagnostics :
@@ -1889,7 +1889,7 @@ gpg_export_keys (CamelCipherContext *context, GPtrArray *keys, CamelStream *ostr
 	res = 0;
 fail:
 	gpg_ctx_free (gpg);
-	
+
 	return res;
 }
 
@@ -1899,9 +1899,9 @@ static void
 camel_gpg_context_class_init (CamelGpgContextClass *klass)
 {
 	CamelCipherContextClass *cipher_class = CAMEL_CIPHER_CONTEXT_CLASS (klass);
-	
+
 	parent_class = CAMEL_CIPHER_CONTEXT_CLASS (camel_type_get_global_classfuncs (camel_cipher_context_get_type ()));
-	
+
 	cipher_class->hash_to_id = gpg_hash_to_id;
 	cipher_class->id_to_hash = gpg_id_to_hash;
 	cipher_class->sign = gpg_sign;
@@ -1916,9 +1916,9 @@ static void
 camel_gpg_context_init (CamelGpgContext *context)
 {
 	CamelCipherContext *cipher = (CamelCipherContext *) context;
-	
+
 	context->always_trust = FALSE;
-	
+
 	cipher->sign_protocol = "application/pgp-signature";
 	cipher->encrypt_protocol = "application/pgp-encrypted";
 	cipher->key_protocol = "application/pgp-keys";
@@ -1934,7 +1934,7 @@ CamelType
 camel_gpg_context_get_type (void)
 {
 	static CamelType type = CAMEL_INVALID_TYPE;
-	
+
 	if (type == CAMEL_INVALID_TYPE) {
 		type = camel_type_register (camel_cipher_context_get_type (),
 					    "CamelGpgContext",
@@ -1945,7 +1945,7 @@ camel_gpg_context_get_type (void)
 					    (CamelObjectInitFunc) camel_gpg_context_init,
 					    (CamelObjectFinalizeFunc) camel_gpg_context_finalise);
 	}
-	
+
 	return type;
 }
 
