@@ -10,12 +10,12 @@
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of version 2 of the GNU Lesser General Public
  * License as published by the Free Software Foundation.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU Lesser General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU Lesser General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301
@@ -42,12 +42,8 @@
 #endif
 
 #include <string.h>
+#include <gtk/gtk.h>
 #include <glib/gi18n-lib.h>
-#include <gtk/gtkversion.h>
-#include <gtk/gtkentry.h>
-#include <gtk/gtkvbox.h>
-#include <gtk/gtkcheckbutton.h>
-#include <gtk/gtkmessagedialog.h>
 
 #include "e-passwords.h"
 #include "libedataserver/e-msgport.h"
@@ -81,7 +77,7 @@ struct _EPassMsg {
 	void (*dispatch) (struct _EPassMsg *);
 
 	/* input */
-	struct _GtkWindow *parent;	
+	struct _GtkWindow *parent;
 	const gchar *component;
 	const gchar *key;
 	const gchar *title;
@@ -214,7 +210,7 @@ ep_password_decode (const gchar *encoded_password)
 	 * to the decoded data to make it a nul-terminated string. */
 
 	gchar *password;
-	gsize length;
+	gsize length = 0;
 
 	password = (gchar *) g_base64_decode (encoded_password, &length);
 	password = g_realloc (password, length + 1);
@@ -307,25 +303,25 @@ ep_clear_passwords_keyring (EPassMsg *msg)
 {
 	GnomeKeyringAttributeList *attributes;
 	GnomeKeyringResult result;
-	GList *matches = NULL, *tmp;	
+	GList *matches = NULL, *tmp;
 	gchar *default_keyring = NULL;
 
 	result = gnome_keyring_get_default_keyring_sync (&default_keyring);
 	if (!default_keyring) {
 	        if (gnome_keyring_create_sync ("default", NULL) != GNOME_KEYRING_RESULT_OK)
 			return;
-	        default_keyring = g_strdup ("default");			
+	        default_keyring = g_strdup ("default");
 	}
 
 	d(g_print ("Get Default %d\n", result));
-	
+
 	/* Not called at all */
 	attributes = gnome_keyring_attribute_list_new ();
 	gnome_keyring_attribute_list_append_string (attributes, "application", "Evolution");
 
 	result = gnome_keyring_find_items_sync (GNOME_KEYRING_ITEM_NETWORK_PASSWORD, attributes, &matches);
 	d(g_print ("Find Items %d\n", result));
-		
+
 	gnome_keyring_attribute_list_free (attributes);
 
 	if (result) {
@@ -336,7 +332,7 @@ ep_clear_passwords_keyring (EPassMsg *msg)
 			d(g_print ("Delete Items %d\n", result));
 		}
 	}
-	
+
 	g_free (default_keyring);
 }
 #endif
@@ -353,8 +349,10 @@ ep_clear_passwords_keyfile (EPassMsg *msg)
 	if (error == NULL)
 		ep_key_file_save ();
 	else {
-		g_warning ("%s", error->message);
-		g_error_free (error);
+		if (error) {
+			g_warning ("%s", error->message);
+			g_error_free (error);
+		}
 	}
 
 	g_free (group);
@@ -382,23 +380,23 @@ ep_forget_passwords_keyring (EPassMsg *msg)
 {
 	GnomeKeyringAttributeList *attributes;
 	GnomeKeyringResult result;
-	GList *matches = NULL, *tmp;	
+	GList *matches = NULL, *tmp;
 	gchar *default_keyring = NULL;
 
 	result = gnome_keyring_get_default_keyring_sync (&default_keyring);
 	if (!default_keyring) {
 	        if (gnome_keyring_create_sync ("default", NULL) != GNOME_KEYRING_RESULT_OK)
 			return;
-	        default_keyring = g_strdup ("default");			
-	}	
+	        default_keyring = g_strdup ("default");
+	}
 	d(g_print ("Get Default %d\n", result));
-	
+
 	attributes = gnome_keyring_attribute_list_new ();
 	gnome_keyring_attribute_list_append_string (attributes, "application", "Evolution");
 
 	result = gnome_keyring_find_items_sync (GNOME_KEYRING_ITEM_NETWORK_PASSWORD, attributes, &matches);
 	d(g_print ("Find Items %d\n", result));
-		
+
 	gnome_keyring_attribute_list_free (attributes);
 
 	if (result) {
@@ -409,7 +407,7 @@ ep_forget_passwords_keyring (EPassMsg *msg)
 			d(g_print ("Delete Items %d\n", result));
 		}
 	}
-	
+
 	g_free (default_keyring);
 
 	/* free up the session passwords */
@@ -469,18 +467,18 @@ ep_remember_password_keyring (EPassMsg *msg)
 			/* LDAP doesnt use username in url. Let the url be the user key. So safe it */
 			gchar *keycopy = g_strdup (msg->key);
 			gint i;
-			
+
 			for (i = 0; i < strlen (keycopy); i ++)
 				if (keycopy[i] == '/' || keycopy[i] =='=')
-					keycopy[i] = '_';		
+					keycopy[i] = '_';
 			uri->user = keycopy;
 		}
-		
+
 		attributes = gnome_keyring_attribute_list_new ();
 		gnome_keyring_attribute_list_append_string (attributes, "user", uri->user);
 		gnome_keyring_attribute_list_append_string (attributes, "server", uri->host);
 		gnome_keyring_attribute_list_append_string (attributes, "application", "Evolution");
-		
+
 		result = gnome_keyring_item_create_sync (NULL, /* Use default keyring */
 						         GNOME_KEYRING_ITEM_NETWORK_PASSWORD, /* type */
 				   			 msg->key, /* name */
@@ -488,14 +486,14 @@ ep_remember_password_keyring (EPassMsg *msg)
 				   			 value, /* password */
 				   			 TRUE, /* Update if already exists */
 				   			 &item_id);
-	
+
 		d(g_print ("Remember %s: %d/%d\n", msg->key, result, item_id));
 
 		gnome_keyring_attribute_list_free (attributes);
 
 		/* now remove it from our session hash */
 		g_hash_table_remove (password_cache, msg->key);
-		
+
 		e_uri_free (uri);
 	}
 }
@@ -547,8 +545,8 @@ ep_forget_password_keyring (EPassMsg *msg)
 {
 	GnomeKeyringAttributeList *attributes;
 	GnomeKeyringResult result;
-	GList *matches = NULL, *tmp;	
-	gchar *default_keyring = NULL;	
+	GList *matches = NULL, *tmp;
+	gchar *default_keyring = NULL;
 	EUri *uri = e_uri_new (msg->key);
 
 	if (!strcmp (uri->protocol, "ldap") && !uri->user) {
@@ -558,25 +556,25 @@ ep_forget_password_keyring (EPassMsg *msg)
 
 		for (i = 0; i < strlen (keycopy); i ++)
 			if (keycopy[i] == '/' || keycopy[i] =='=')
-				keycopy[i] = '_';		
+				keycopy[i] = '_';
 		uri->user = keycopy;
 	}
-	    
+
 	g_hash_table_remove (password_cache, msg->key);
 
 	if (!uri->host && !uri->user)
 		/* No need to remove from keyring for pass phrases */
 		goto exit;
-	
+
 	result = gnome_keyring_get_default_keyring_sync (&default_keyring);
 	if (!default_keyring) {
 	        if (gnome_keyring_create_sync ("default", NULL) != GNOME_KEYRING_RESULT_OK)
 			goto exit;
-	        default_keyring = g_strdup ("default");			
+	        default_keyring = g_strdup ("default");
 	}
 
 	d(g_print ("Get Default %d\n", result));
-	
+
 	attributes = gnome_keyring_attribute_list_new ();
 	gnome_keyring_attribute_list_append_string (attributes, "user", uri->user);
 	gnome_keyring_attribute_list_append_string (attributes, "server", uri->host);
@@ -584,7 +582,7 @@ ep_forget_password_keyring (EPassMsg *msg)
 
 	result = gnome_keyring_find_items_sync (GNOME_KEYRING_ITEM_NETWORK_PASSWORD, attributes, &matches);
 	d(g_print ("Find Items %d\n", result));
-		
+
 	gnome_keyring_attribute_list_free (attributes);
 
 	if (result) {
@@ -607,17 +605,17 @@ ep_forget_password_keyring (EPassMsg *msg)
 				} else if (!strcmp (attr->name, "server")) {
 					present++;
 					if (strcmp (attr->value.string, uri->host))
-						accept = FALSE;						
+						accept = FALSE;
 				}
 			}
 				if (present == 2 && accept) {
 					result = gnome_keyring_item_delete_sync (default_keyring, ((GnomeKeyringFound *) tmp->data)->item_id);
-					d(g_print ("Delete Items %s %s %d\n", uri->host, uri->user, result));			
+					d(g_print ("Delete Items %s %s %d\n", uri->host, uri->user, result));
 				}
-		}	
+		}
 
 	}
-	
+
 	g_free (default_keyring);
 
 exit:
@@ -671,14 +669,14 @@ ep_get_password_keyring (EPassMsg *msg)
 	gchar *passwd;
 	GnomeKeyringAttributeList *attributes;
 	GnomeKeyringResult result;
-	GList *matches = NULL, *tmp;	
+	GList *matches = NULL, *tmp;
 
 	passwd = g_hash_table_lookup (password_cache, msg->key);
 	if (passwd) {
 		msg->password = g_strdup (passwd);
 	} else {
 		EUri *uri = e_uri_new (msg->key);
-		
+
 		if (!strcmp (uri->protocol, "ldap") && !uri->user) {
 			/* LDAP doesnt use username in url. Let the url be the user key. So safe it */
 			gchar *keycopy = g_strdup (msg->key);
@@ -686,10 +684,10 @@ ep_get_password_keyring (EPassMsg *msg)
 
 			for (i = 0; i < strlen (keycopy); i ++)
 				if (keycopy[i] == '/' || keycopy[i] =='=')
-					keycopy[i] = '_';		
+					keycopy[i] = '_';
 			uri->user = keycopy;
 		}
-		
+
 		if (uri->host &&  uri->user) {
 			/* We dont store passphrases.*/
 
@@ -701,7 +699,7 @@ ep_get_password_keyring (EPassMsg *msg)
 
 			result = gnome_keyring_find_items_sync (GNOME_KEYRING_ITEM_NETWORK_PASSWORD, attributes, &matches);
 			d(g_print ("Find Items %d\n", result));
-			
+
 			gnome_keyring_attribute_list_free (attributes);
 
 			if (result) {
@@ -726,20 +724,20 @@ ep_get_password_keyring (EPassMsg *msg)
 						} else if (!strcmp (attr->name, "server") && attr->value.string) {
 							present++;
 							if (strcmp (attr->value.string, uri->host))
-								accept = FALSE;						
+								accept = FALSE;
 						}
 					}
 					if (present == 2 && accept) {
 						msg->password = g_strdup (((GnomeKeyringFound *) tmp->data)->secret);
 						break;
 					}
-				}	
+				}
 			}
 		}
-		
+
 		e_uri_free (uri);
 	}
-}	
+}
 #endif
 
 static void
@@ -762,8 +760,10 @@ ep_get_password_keyfile (EPassMsg *msg)
 		msg->password = ep_password_decode (password);
 		g_free (password);
 	} else {
-		g_warning ("%s", error->message);
-		g_error_free (error);
+		if (error) {
+			g_warning ("%s", error->message);
+			g_error_free (error);
+		}
 	}
 
 	g_free (group);
@@ -822,7 +822,7 @@ pass_response (GtkDialog *dialog, gint response, void *data)
 				ep_add_password (msg);
 			}
 			if (*msg->remember && type == E_PASSWORDS_REMEMBER_FOREVER)
-				ep_remember_password (msg);				    
+				ep_remember_password (msg);
 
 			msg->noreply = noreply;
 		}
@@ -841,7 +841,7 @@ pass_response (GtkDialog *dialog, gint response, void *data)
 	while (mn) {
 		if ((mw->dispatch == ep_forget_password
 		     || mw->dispatch == ep_get_password
-		     || mw->dispatch == ep_ask_password)		    
+		     || mw->dispatch == ep_ask_password)
 		    && (strcmp (mw->component, msg->component) == 0
 			&& strcmp (mw->key, msg->key) == 0)) {
 			e_dlist_remove ((EDListNode *)mw);
@@ -862,71 +862,121 @@ pass_response (GtkDialog *dialog, gint response, void *data)
 static void
 ep_ask_password (EPassMsg *msg)
 {
-	GtkWidget *vbox;
+	GtkWidget *widget;
+	GtkWidget *container;
 	gint type = msg->flags & E_PASSWORDS_REMEMBER_MASK;
 	guint noreply = msg->noreply;
+	gboolean visible;
 	AtkObject *a11y;
 
 	msg->noreply = 1;
 
-	/*password_dialog = (GtkDialog *)e_error_new (msg->parent, "mail:ask-session-password", msg->prompt, NULL);*/
-	password_dialog = (GtkDialog *)gtk_message_dialog_new (msg->parent,
-							       0,
-							       GTK_MESSAGE_QUESTION,
-							       GTK_BUTTONS_OK_CANCEL,
-							       "%s", msg->prompt);
-	gtk_window_set_title (GTK_WINDOW (password_dialog), msg->title);
+	widget = gtk_dialog_new_with_buttons (
+		msg->title, msg->parent, 0,
+		GTK_STOCK_CANCEL, GTK_RESPONSE_REJECT,
+		GTK_STOCK_OK, GTK_RESPONSE_ACCEPT,
+		NULL);
+	gtk_dialog_set_has_separator (GTK_DIALOG (widget), FALSE);
+	gtk_dialog_set_default_response (
+		GTK_DIALOG (widget), GTK_RESPONSE_ACCEPT);
+        gtk_window_set_resizable (GTK_WINDOW (widget), FALSE);
+	gtk_container_set_border_width (GTK_CONTAINER (widget), 12);
+	password_dialog = GTK_DIALOG (widget);
 
-	gtk_widget_ensure_style (GTK_WIDGET (password_dialog));
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (password_dialog)->vbox), 0);
-	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (password_dialog)->action_area), 12);
+        /* Override GtkDialog defaults */
+	widget = password_dialog->vbox;
+	gtk_box_set_spacing (GTK_BOX (widget), 12);
+	gtk_container_set_border_width (GTK_CONTAINER (widget), 0);
+	widget = password_dialog->action_area;
+	gtk_box_set_spacing (GTK_BOX (widget), 12);
+	gtk_container_set_border_width (GTK_CONTAINER (widget), 0);
 
-	gtk_dialog_set_default_response (password_dialog, GTK_RESPONSE_OK);
+	/* Table */
+	container = gtk_table_new (2, 3, FALSE);
+	gtk_table_set_col_spacings (GTK_TABLE (container), 12);
+	gtk_table_set_row_spacings (GTK_TABLE (container), 12);
+	gtk_table_set_row_spacing (GTK_TABLE (container), 1, 6);
+	gtk_widget_show (container);
 
-	vbox = gtk_vbox_new (FALSE, 12);
-	gtk_widget_show (vbox);
-	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (password_dialog)->vbox), vbox, TRUE, FALSE, 0);
-	gtk_container_set_border_width ((GtkContainer *)vbox, 12);
-	
-	msg->entry = gtk_entry_new ();
+	gtk_box_pack_start (
+		GTK_BOX (password_dialog->vbox),
+		container, FALSE, TRUE, 0);
 
-	a11y = gtk_widget_get_accessible (msg->entry);
+	/* Question Image */
+	widget = gtk_image_new_from_stock (
+		GTK_STOCK_DIALOG_QUESTION,
+		GTK_ICON_SIZE_DIALOG);
+	gtk_misc_set_alignment (GTK_MISC (widget), 0.0, 0.0);
+	gtk_widget_show (widget);
+
+	gtk_table_attach (
+		GTK_TABLE (container), widget,
+		0, 1, 0, 3, GTK_FILL, GTK_EXPAND | GTK_FILL, 0, 0);
+
+	/* Password Label */
+	widget = gtk_label_new (NULL);
+	gtk_label_set_line_wrap (GTK_LABEL (widget), TRUE);
+        gtk_label_set_markup (GTK_LABEL (widget), msg->prompt);
+	gtk_misc_set_alignment (GTK_MISC (widget), 0.0, 0.5);
+	gtk_widget_show (widget);
+
+	gtk_table_attach (
+		GTK_TABLE (container), widget,
+		1, 2, 0, 1, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+
+	/* Password Entry */
+	widget = gtk_entry_new ();
+	a11y = gtk_widget_get_accessible (widget);
+	visible = !(msg->flags & E_PASSWORDS_SECRET);
 	atk_object_set_description (a11y, msg->prompt);
-	gtk_entry_set_visibility ((GtkEntry *)msg->entry, !(msg->flags & E_PASSWORDS_SECRET));
-	gtk_entry_set_activates_default ((GtkEntry *)msg->entry, TRUE);
-	gtk_box_pack_start (GTK_BOX (vbox), msg->entry, TRUE, FALSE, 3);
-	gtk_widget_show (msg->entry);
-	gtk_widget_grab_focus (msg->entry);
-	
+	gtk_entry_set_visibility (GTK_ENTRY (widget), visible);
+	gtk_entry_set_activates_default (GTK_ENTRY (widget), TRUE);
+	gtk_widget_grab_focus (widget);
+	gtk_widget_show (widget);
+	msg->entry = widget;
+
 	if ((msg->flags & E_PASSWORDS_REPROMPT)) {
 		ep_get_password (msg);
-		if (msg->password) {
-			gtk_entry_set_text ((GtkEntry *) msg->entry, msg->password);
+		if (msg->password != NULL) {
+			gtk_entry_set_text (GTK_ENTRY (widget), msg->password);
 			g_free (msg->password);
 			msg->password = NULL;
 		}
 	}
 
+	gtk_table_attach (
+		GTK_TABLE (container), widget,
+		1, 2, 1, 2, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
+
 	/* static password, shouldn't be remembered between sessions,
 	   but will be remembered within the session beyond our control */
 	if (type != E_PASSWORDS_REMEMBER_NEVER) {
 		if (msg->flags & E_PASSWORDS_PASSPHRASE) {
-			msg->check = gtk_check_button_new_with_mnemonic (type == E_PASSWORDS_REMEMBER_FOREVER
-									? _("_Remember this passphrase")
-									: _("_Remember this passphrase for the remainder of this session"));
+			widget = gtk_check_button_new_with_mnemonic (
+				(type == E_PASSWORDS_REMEMBER_FOREVER)
+				? _("_Remember this passphrase")
+				: _("_Remember this passphrase for"
+				    " the remainder of this session"));
 		} else {
-			msg->check = gtk_check_button_new_with_mnemonic (type == E_PASSWORDS_REMEMBER_FOREVER
-									? _("_Remember this password")
-									: _("_Remember this password for the remainder of this session"));
-			
+			widget = gtk_check_button_new_with_mnemonic (
+				(type == E_PASSWORDS_REMEMBER_FOREVER)
+				? _("_Remember this password")
+				: _("_Remember this password for"
+				    " the remainder of this session"));
 		}
-		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (msg->check), *msg->remember);
-		gtk_box_pack_start (GTK_BOX (vbox), msg->check, TRUE, FALSE, 3);
-		if ((msg->flags & E_PASSWORDS_DISABLE_REMEMBER))
-			gtk_widget_set_sensitive (msg->check, FALSE);
-		gtk_widget_show (msg->check);
+
+		gtk_toggle_button_set_active (
+			GTK_TOGGLE_BUTTON (widget), *msg->remember);
+		if (msg->flags & E_PASSWORDS_DISABLE_REMEMBER)
+			gtk_widget_set_sensitive (widget, FALSE);
+		gtk_widget_show (widget);
+		msg->check = widget;
+
+		gtk_table_attach (
+			GTK_TABLE (container), widget,
+			1, 2, 2, 3, GTK_EXPAND | GTK_FILL, GTK_FILL, 0, 0);
 	}
-	
+
 	msg->noreply = noreply;
 
 	g_signal_connect (password_dialog, "response", G_CALLBACK (pass_response), msg);
@@ -974,7 +1024,7 @@ e_passwords_init (void)
 
 /**
  * e_passwords_cancel:
- * 
+ *
  * Cancel any outstanding password operations and close any dialogues
  * currently being shown.
  **/
@@ -1010,8 +1060,8 @@ e_passwords_shutdown (void)
 
 /**
  * e_passwords_set_online:
- * @state: 
- * 
+ * @state:
+ *
  * Set the offline-state of the application.  This is a work-around
  * for having the backends fully offline aware, and returns a
  * cancellation response instead of prompting for passwords.
@@ -1034,7 +1084,7 @@ void
 e_passwords_forget_passwords (void)
 {
 	EPassMsg *msg = ep_msg_new (ep_forget_passwords);
-	
+
 	ep_msg_send (msg);
 	ep_msg_free (msg);
 }
@@ -1047,7 +1097,7 @@ e_passwords_forget_passwords (void)
 void
 e_passwords_clear_passwords (const gchar *component_name)
 {
-	EPassMsg *msg = ep_msg_new (ep_clear_passwords);		
+	EPassMsg *msg = ep_msg_new (ep_clear_passwords);
 
 	msg->component = component_name;
 	ep_msg_send (msg);
@@ -1201,6 +1251,6 @@ e_passwords_ask_password (const gchar *title, const gchar *component_name,
 	passwd = msg->password;
 	msg->password = NULL;
 	ep_msg_free (msg);
-	
+
 	return passwd;
 }
